typedef union {
        char *string;
        int number;
        grad_uint32_t ipaddr;
        Variable *ident;
        grad_avp_t *pair;
        grad_avp_t *vector;
        struct {
                grad_avp_t *head, *tail;
        } pair_list;
        Variable variable;
	grad_symtab_t *symtab;
	enum grad_operator op;
} YYSTYPE;
#define	EOL	257
#define	AUTH	258
#define	ACCT	259
#define	SEND	260
#define	EXPECT	261
#define	EQ	262
#define	LT	263
#define	GT	264
#define	NE	265
#define	LE	266
#define	GE	267
#define	PRINT	268
#define	ALL	269
#define	VARS	270
#define	EXIT	271
#define	IDENT	272
#define	NAME	273
#define	NUMBER	274
#define	QUOTE	275
#define	IPADDRESS	276


extern YYSTYPE yylval;
